aboutsummaryrefslogtreecommitdiffstats
path: root/executor
diff options
context:
space:
mode:
Diffstat (limited to 'executor')
-rw-r--r--executor/common.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/executor/common.h b/executor/common.h
index 6e92743f5..b6b3324d9 100644
--- a/executor/common.h
+++ b/executor/common.h
@@ -82,9 +82,9 @@ __attribute__((noreturn)) void fail(const char* msg, ...)
vfprintf(stderr, msg, args);
va_end(args);
fprintf(stderr, " (errno %d)\n", e);
// ENOMEM is frequent cause of failures in fuzzing context,
// so handle it here as non-fatal error.
- doexit(e == ENOMEM ? kRetryStatus : kFailStatus);
+ doexit((e == ENOMEM || e == EAGAIN) ? kRetryStatus : kFailStatus);
}
#if defined(SYZ_EXECUTOR)
@@ -82,9 +82,9 @@ __attribute__((noreturn)) void fail(const char* msg, ...)
va_end(args);
fprintf(stderr, " (errno %d)\n", e);
- // ENOMEM is frequent cause of failures in fuzzing context,
+ // ENOMEM/EAGAIN is frequent cause of failures in fuzzing context,
// so handle it here as non-fatal error.